FaceRecognitionResultCode class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- allLivenessSuccess → const int
- cancel → const int
- colorLivenessFailed → const int
- colorLivenessLightTooHigh → const int
- colorLivenessSuccess → const int
- motionLivenessSuccess → const int
- motionLivenessTimeout → const int
- noBaseFaceFeature → const int
- noFaceFeature → const int
- noFaceMulti → const int
- notAllowMultiFaces → const int
- silentLivenessFailed → const int
- verifyFailed → const int
- verifySuccess → const int