FaceRecognitionResult class
FaceRecognition operation result.
Constructors
- FaceRecognitionResult({required int code, String? message, double? similarity, double? livenessValue, String? faceBase64, String? faceFeature})
- FaceRecognitionResult.fromMap(Map map)
-
factory
Properties
- code → int
-
Result code. See FaceRecognitionResultCode.
final
- faceBase64 → String?
-
Base64 string of the captured face image.
final
- faceFeature → String?
-
Face feature string.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
Whether the operation was successful.
no setter
- livenessValue → double?
-
Liveness detection score.
final
- message → String?
-
Tip message or error description.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- similarity → double?
-
Face similarity score
0.0, 1.0.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited